package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````(`/@`!````2!Y```````!``````````+B;````
M`````````$``.``(`$``'``;``8````$````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````5`````````!4``````````0`````````!````
M!0````````````````!``````````$```````"B6````````*)8`````````
M$`````````$````&````*)8````````HID```````"BF0```````2`0`````
M``#Y"``````````0`````````@````8````HE@```````"BF0```````**9`
M`````````@`````````"````````"``````````$````!````!@"````````
M&`)````````8`D```````#@`````````.``````````$`````````%#E=&0$
M````5)4```````!4E4```````%250```````U`````````#4``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$``````````O;&EB97AE8R]L9"UE;&8N<V\N,@`````*````
M!`````$```!$<F%G;VY&;'D```#`)PD`"@````0````@````1')A9V]N1FQY
M`````````````````````````````````````````#T````2````````````
M`````````````$X````2`````````````````````````%0````2````````
M`````````````````%L````2`````````````````````````&,````2````
M`````````````````````&H````2`````````````````````````'(````2
M`````````````````````````(H````2`````````````````````````)H`
M```2`````````````````````````*$````2````````````````````````
M`*8````2`````````````````````````*\````2````````````````````
M`````+T````2`````````````````````````,0````2````````````````
M`````````,X````2`````````````````````````-P````2````````````
M`````````````/$````2``````````````````````````0!```2````````
M`````````````````!,!```2`````````````````````````"L!```2````
M`````````````````````%X!```2`````````````````````````'D!```2
M`````````````````````````($!```2`````````````````````````(T!
M```2`````````````````````````*(!```2````````````````````````
M`*X!```2`````````````````````````+X!```2````````````````````
M`````,\!```2`````````````````````````-8!```2````````````````
M`````````-P!```2`````````````````````````.X!```2````````````
M`````````````/X!```2``````````````````````````,"```2````````
M``````````````````@"```2`````````````````````````!$"```2````
M`````````````````````!<"```2`````````````````````````!P"```2
M`````````````````````````","```2`````````````````````````"H"
M```2`````````````````````````"\"```2````````````````````````
M`#<"```2`````````````````````````#\"```2````````````````````
M`````%$"```2`````````````````````````%D"```6````````````````
M`````````%\"```2`````````````````````````&<"```2````````````
M`````````````'L"```2`````````````````````````(X"```2````````
M`````````````````)4"```2`````````````````````````*X"```2````
M`````````````````````+4"```2`````````````````````````+X"```2
M`````````````````````````,<"```2`````````````````````````,X"
M```2`````````````````````````.\"```2````````````````````````
M`$<#```2`````````````````````````&X#```2````````````````````
M`````)$#```2`````````````````````````)\#```2````````````````
M`````````+D#```@`````````````````````````-,#```@````````````
M`````````````'D#```2````H!E``````````````````/H#```1`!0`,*I`
M```````(`````````&T!```2``P`L#9```````!U`````````($"```2``P`
M`"U````````\!P```````/4#```2``P`T!M```````#L`0```````!0$```2
M``T`>%%``````````````````"D#```2``P`0"=```````"_`0```````#8#
M```2``P`,"=````````#`````````%@#```2``P`0#1```````!O`@``````
M`.\#```2``H`T!=```````````````````8````0`!$`<*I`````````````
M``````$````0`!$`(:]``````````````````.,!```2``P`L$U```````"@
M`0```````)P"```2``P`0"Q```````"Q`````````/4"```2``P`L"M`````
M``!J`````````!P#```2``P``"E````````D`````````(D#```2``P`L"9`
M```````J`````````#H!```2````(!M``````````````````!`#```2``P`
M,"E```````"[`````````!(````0`!$`<*I``````````````````.<````1
M`!0`2*I````````(`````````$L!```2````$!M```````````````````T$
M```2``P`2!Y```````!-`0```````/4!```2``P`4$U```````!4````````
M`*X#```1`!@``*]````````$``````````4$```1`!@`@*I````````(````
M`````$<"```1`!@`"*]````````(`````````-0"```2``P`("Q````````=
M`````````,4!```2``P`4$]```````#U`0```````!X!```1`!@`(*]`````
M```!``````````,#```2``P`\"E```````"U`0```````!D````1`!@`P*Y`
M``````!```````````!?96YD`%]?8G-S7W-T87)T`%]E9&%T80!?7W-T86-K
M7V-H:U]G=6%R9`!$1C0P-"XP`&QI8F,N<V\N.`!?7W-T86-K7V-H:U]F86EL
M`&%B;W)T`&UA;&QO8P!M96UM;W9E`'-T<FQE;@!S=')N8VUP`%]I;FET7W1L
M<P!$1G!R:79A=&5?,2XP`%]R=&QD7V-A;&Q?:6YI=`!M96UC<'D`97AI=`!P
M97)L7W)U;@!097)L7W-Y<U]T97)M`&%T97AI=`!P97)L7V9R964`<&5R;%]D
M97-T<G5C=`!P97)L7W!A<G-E`&UY7W!A<E]P;`!097)L7W-A9F5S>7-M86QL
M;V,`<&5R;%]C;VYS=')U8W0`<&5R;%]A;&QO8P!03%]D;U]U;F1U;7``<'1H
M<F5A9%]A=&9O<FL`4&5R;%]A=&9O<FM?;&]C:P!097)L7V%T9F]R:U]U;FQO
M8VL`4&5R;%]S>7-?:6YI=#,`<&%R7V-L96%N=7``<W1R;F-P>0!097)L7VUG
M7W-E=`!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V=E=%]S=@!097)L7V=V
M7V9E=&-H<'8`<W1R8VUP`'-H85]F:6YA;`!S=')D=7``8VQO<V4`<W1R8VAR
M`'-H85]U<&1A=&4`<W1R=&]K`'-H85]I;FET`&9R964`<F5A9`!C;&]S961I
M<@!L<V5E:P!S=&%T`&=E='!I9`!U;FQI;FL`;W!E;@!R96%D9&ER`&9P<FEN
M=&8`<W!R:6YT9@!?7W-T9&5R<G``<F5A;&QO8P!E<G)N;P!O<&5N9&ER`'!T
M:')E861?9V5T<W!E8VEF:6,`;6MD:7(`<&%R7VUK=&UP9&ER`'-T<G-T<@!M
M96UC:'(`<&%R7W-E='5P7VQI8G!A=&@`86-C97-S`&=E='!W=6ED`')E861L
M:6YK`&=E='5I9`!R;61I<@!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!L
M<W1A=`!P87)?96YV7V-L96%N`'!A<E]I;FET7V5N=@!P87)?9&ER;F%M90!P
M87)?8F%S96YA;64`<&%R7V9I;F1P<F]G`'!A<E]C=7)R96YT7V5X96,`4&5R
M;%]N97=84U]F;&%G<P!84U]);G1E<FYA;'-?4$%27T)/3U0`4&5R;%]N97=8
M4P!B;V]T7T1Y;F%,;V%D97(`>'-?:6YI=`!097)L7W-V7W-E='!V`%!E<FQ?
M<W9?<V5T<'9N`%!,7W1H<E]K97D`7TE435]R96=I<W1E<E1-0VQO;F5486)L
M90!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7VEN:70`;6%I;@!?7W!R
M;V=N86UE`&5N=FER;VX`7W-T87)T`%]F:6YI`&QI8G!E<FPN<V\N-2XS,@!L
M:6)P=&AR96%D+G-O+C``;&EB9&PN<V\N,`!L:6)M+G-O+C0`;&EB8W)Y<'0N
M<V\N-`!L:6)U=&EL+G-O+C0`+W5S<B]L:6(O9V-C.#`Z+W5S<B]L;V-A;"]L
M:6(O<&5R;#4O-2XS,B]M86-H+T-/4D4`````$0```#X````$````"````"`<
M$``%0`2`*`!`!)"&`8S"(0$@20`$&XB".$&Z!`((/@```$````!$````2```
M`$D```!/````4````%$```!3````5````%4```!6````6````%H```!;````
M`````%T```!Z\$IKO5!VGF[%WQ_.WD<M:G^:?.O3[PX@_^0.+L6;MM1DU'RY
MC?$.V7%8'+KCDGQ"^M>'^J%L8+(!BV_B1\8!P^4_+(?YG(%GK\QF0D75[(D'
M<-/)U;)Q,V+;[16,)<Q6I)N6I]VC:^85`X-_J9R;:QJ>4`J*$%>CX/M)(6)D
M!P```@`"``(``@`"``(``P`#``(``@```````@`````````````````"````
M`@````````````(``@`"``(``@`"``(``@`"``(``@`"``(``@`"``(``@`"
M``(``@`"``(``@`"``(``@`"``(``@````````````````````$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$````!``$``0````$``0`!``$``@`!
M``$``0`!``(``0`"`#,````0`````````%`WEP@```(`*P```!````"0M'X`
M```#`'P`````````**A````````2````+````````````````*]````````%
M````5@``````````````"*]````````%````6```````````````(*]`````
M```%````6P``````````````P*Y````````%````70``````````````2*A`
M```````'`````@``````````````4*A````````'````!P``````````````
M6*A````````'````"```````````````8*A````````'````#0``````````
M````:*A````````'````"@``````````````<*A````````'````!@``````
M````````>*A````````'`````0``````````````@*A````````'````!0``
M````````````B*A````````'`````P``````````````D*A````````'````
M!```````````````F*A````````'````*P``````````````H*A````````'
M````+0``````````````J*A````````'````*```````````````L*A`````
M```'````*@``````````````N*A````````'````)```````````````P*A`
M```````'````)@``````````````R*A````````'````(```````````````
MT*A````````'````(@``````````````V*A````````'````-@``````````
M````X*A````````'````-P``````````````Z*A````````'````,@``````
M````````\*A````````'````-```````````````^*A````````'````,0``
M`````````````*E````````'````+@``````````````"*E````````'````
M.P``````````````$*E````````'````.@``````````````&*E````````'
M````/@``````````````(*E````````'````'@``````````````**E`````
M```'````'P``````````````,*E````````'````&P``````````````.*E`
M```````'````'```````````````0*E````````'````%@``````````````
M2*E````````'````-0``````````````4*E````````'````,P``````````
M````6*E````````'````,```````````````8*E````````'````+P``````
M````````:*E````````'````*0``````````````<*E````````'````)P``
M````````````>*E````````'````)0``````````````@*E````````'````
M(P``````````````B*E````````'````(0``````````````D*E````````'
M````'0``````````````F*E````````'````&@``````````````H*E`````
M```'````&0``````````````J*E````````'````&```````````````L*E`
M```````'````%P``````````````N*E````````'````.0``````````````
MP*E````````'````.```````````````R*E````````'````%0``````````
M````T*E````````'````4P``````````````V*E````````'````3P``````
M````````X*E````````'````%```````````````Z*E````````'````$P``
M````````````\*E````````'````$@``````````````^*E````````'````
M$0```````````````*I````````'````$```````````````"*I````````'
M````#P``````````````$*I````````'````#@``````````````&*I`````
M```'````#```````````````(*I````````'````"P``````````````**I`
M```````'````"0``````````````2(/L".A["```Z&<Y``!(@\0(PP``````
M``````````#_-4*0``#_)420``"0D)"0_R5"D```:`````#IX/____\E.I``
M`&@!````Z=#_____)3*0``!H`@```.G`_____R4JD```:`,```#IL/____\E
M(I```&@$````Z:#_____)1J0``!H!0```.F0_____R42D```:`8```#I@/__
M__\E"I```&@'````Z7#_____)0*0``!H"````.E@_____R7ZCP``:`D```#I
M4/____\E\H\``&@*````Z4#_____)>J/``!H"P```.DP_____R7BCP``:`P`
M``#I(/____\EVH\``&@-````Z1#_____)=*/``!H#@```.D`_____R7*CP``
M:`\```#I\/[___\EPH\``&@0````Z>#^____);J/``!H$0```.G0_O___R6R
MCP``:!(```#IP/[___\EJH\``&@3````Z;#^____):*/``!H%````.F@_O__
M_R6:CP``:!4```#ID/[___\EDH\``&@6````Z8#^____)8J/``!H%P```.EP
M_O___R6"CP``:!@```#I8/[___\E>H\``&@9````Z5#^____)7*/``!H&@``
M`.E`_O___R5JCP``:!L```#I,/[___\E8H\``&@<````Z2#^____)5J/``!H
M'0```.D0_O___R52CP``:!X```#I`/[___\E2H\``&@?````Z?#]____)4*/
M``!H(````.G@_?___R4ZCP``:"$```#IT/W___\E,H\``&@B````Z<#]____
M)2J/``!H(P```.FP_?___R4BCP``:"0```#IH/W___\E&H\``&@E````Z9#]
M____)1*/``!H)@```.F`_?___R4*CP``:"<```#I</W___\E`H\``&@H````
MZ6#]____)?J.``!H*0```.E0_?___R7RC@``:"H```#I0/W___\EZHX``&@K
M````Z3#]____)>*.``!H+````.D@_?___R7:C@``:"T```#I$/W___\ETHX`
M`&@N````Z0#]____)<J.``!H+P```.GP_/___R7"C@``:#````#IX/S___\E
MNHX``&@Q````Z=#\____);*.``!H,@```.G`_/___R6JC@``:#,```#IL/S_
M__\EHHX``&@T````Z:#\____)9J.``!H-0```.F0_/___R62C@``:#8```#I
M@/S___\EBHX``&@W````Z7#\____)8*.``!H.````.E@_/___R5ZC@``:#D`
M``#I4/S___\E<HX``&@Z````Z4#\____)6J.``!H.P```.DP_/___R5BC@``
M:#P```#I(/S__U-(@^PP2(L%Y)(``$B)1"0H,<")?"0<2(U\)!Q(B70D$$B-
M="002(E4)`A(C50D".C[_O__NA`;0`"_(!M``$B)UN@9____@#T"DP```'4O
MZ!O___](B06,D@``2(7`#X1X`0``2(G'Z!/___^+/;V2``#H*/W__\:`$0D`
M``"+/:N2``#H%OW__XL]H)(``("(P@,```+H!/W__X"(P@,```&+1"0<C7@$
MC5@#2&/_2,'G`^C7_O__2(M\)!!$BT0D'$B)!1:2``!(BQ=(QT`(9U-``$C'
M0!AJ4T``2(D02(L5D8T``$B)4!!!@_@!#X[=````2(/'"$&#P`.^!````$R+
M#TACUH/&`4B#QPA,B0S003GP=>I-8\!)P>`#2L<$``````!(BSVZD0``B=I%
M,<!(B<&^X"9``.A@_O__B<.%P'1)2(L]FY$``.A>_O__,<!(C70D)+\J4D``
MZ#T#``!(A<!T-TB+/7F1``#H3/[__^A7_O__B=A(BTPD*$@S#6F1``!U7DB#
MQ#!;PTB+/5*1``#H1?[__XG#ZZ=(BSTRD0``2(7_=`?H,!D``.NVO]A10`!(
MC70D).C?`@``2(G'2(D%#9$``$B%P'28Z]E!N"````#I0O___[\!````Z(GZ
M___HI/K__[@`````2#T`````<SI52(GE0513@STQXK__)74@2(G#3(LC_U,0
M28D$)$B#PQA(@?L`````<PN#>P@E=./H`OK__UM!7%W#PU5(B>532(/L"+@`
M````2"T`````2,'X`TB)PW41Z%(S``!(@\0(6UW#2(7;=.](@^L!2(L$W0``
M``!(@_@!=NG_T.OE54B)Y4%7059!54%44TB#[!A(B?-,BR]%B>],C7<(26/%
M3(UDQQ!(@ST*C````'17187M?A=(BT<(2(7`=`Y(B06CBP``#[80A-)U3^AW
M^?__Z(+Y__^X**9``$B%P'1-2(G?Z(#Y__^X**9``$B%P'1"3(GB3(GV1(GO
MZ`C]__^)Q^AQ^?__3(DEJHL``.N@2(/``0^V$(32=+&`^B]U\$B-4`%(B14]
MBP``Z^/HPO[__^NTOP0>0`#H*OG__[@`````2"T`````2,'X`TB)1<AT++L`
M````ZPI(@\,!2#E=R'0;2(L$W0````!(@_@!=NA,B>),B?9$B?__T.O;Z(3X
M__^X`````$@M`````$C!^`-(B47(#X15____NP````#K#DB#PP%(.5W(#X1`
M____2(L$W0````!(@_@!=N1,B>),B?9$B?__T.O7N'"J0`!(/7"J0`!T%[@`
M````2(7`=`U52(GEOW"J0`#_T%W#P[YPJD``2('N<*I``$C!_@-(B?!(P>@_
M2`'&2-'^=!>X`````$B%P'0-54B)Y;]PJD``_]!=P\.`/9"*````=5E52(GE
M0513NVBJ0`!(@>M@JD``2,'[`TB#ZP%!O&"J0`!(BP5NB@``2#G8<QM(@\`!
M2(D%7HH``$'_%,1(BP53B@``2#G8<N7H3O___\8%.HH```%;05Q=P\-52(GE
MZ%W___]=PV9F9F8N#Q^$````````````05=!5D%505154TB#[`A(A?\/A*L`
M``!,BSWRB0``387_#X2;````#[8'A,!T!#P]=5Y%,>1)BQ](A=MT.4F)]4F)
M_DUCY$R)_0\?@`````!,B>),B?9(B=_H@O?__X7`=0="@#PC/71'2(/%"$B+
M70!(A=MUVDB#Q`A(B=A;74%<05U!7D%?PP\?A```````28G\28/$`4$/M@0D
MA,!T!#P]=>]!*?SKC`\?@`````!,*?U*C5PC`4C!_0-!B6T`Z[0QV^NP9BX/
M'X0``````%-(B?M(@^P02(L%<8T``$B)1"0(,<!F+@\?A```````,<!(C70D
M!$B)W^@!____2(7`="Y(8U0D!$B+!0")``!(C0302(M0"$B)$$B%TG302(/`
M"$B+4`A(B1!(A=)U\.N^2(M$)`A(,P42C0``=09(@\006\/HI?;__P\?1```
M05=!5D%505152(GU4TB)^TB#["A(BP7EC```2(E$)!@QP#'`@#X]#Y3`2`'%
M2(GOZ'OV__](C70D%$B)WTF)Q#'`Z&G^__](A<`/A`0!``!(B<=)B<7H5?;_
M_TPYX`^#T````$QC="042<'F`P^V`X3`#X2<`0``/#T/A)0!``!(B=A(@\`!
M#[80A-)T!8#Z/77P2"G82)A*C7P@`DP#-1R(``#H%_;__TF)!DB%P`^$<P$`
M`$B+!02(``!(8U0D%$B-2P%(BQ30#[8#B`*$P'0D/#UU#NL>#Q^$``````"$
MP'022(/!`0^V0?](@\(!B`(\/77JQ@(],<`/'T0```^V3`4`B$P"`4B#P`&$
MR77O,<!(BUPD&$@S'>&+```/A0T!``!(@\0H6UU!7$%=05Y!7\,QP&8N#Q^$
M```````/ME0%`$&(5`4`2(/``832=>[KO4R+/66'``!)@S\`#X2V````3(GX
M,=+K!P\?0`!$B>I(@\`(1(UJ`4B#.`!U[XUR`TAC]DC!Y@.+!4^+``"%P'5;
MQP5!BP```0```$B)]^@9]?__2(7`='Q-8\5,B?Y(B<=.C33%`````$R)1"0(
M3(GRZ`;U__],BT0D"$B)!>J&``!(B<%*QT3!"`````!$B6PD%.F!_O__#Q]`
M`$R)_^CH]/__2(G!2(D%OH8``$B%P'0A36/%3HTTQ0````#KQ3'`Z7W^__^^
M$````$4Q[>EC____N/_____IX?[__^AI]/__9@\?A```````055!5%532('L
MF````$B+!:R*``!(B80DB````#'`2(7_=`B`/P!(B?UU)4B+A"2(````2#,%
MAHH```^%_````$B!Q)@```!;74%<05W#9I#H6_3__TF)Q$B%P'3.3(GGZ%OT
M__](A<`/A+(```!(C5@0OXE10`"Y`@```$B)WO.F#Y?`'`"$P'33OXM10`"Y
M`P```$B)WO.F#Y?`'`"$P'2[2(GOZ,;S__](B=])B<7HN_/__T&-?`4"2&/_
MZ+[S__](B=E(B>J^CE%``$F)Q4B)QS'`Z/;S__],B>](B>;H^_/__TR)[X/X
M_W0/#[=$)!!F)0#P9CT`0'0YZ._S__],B>_H]_/__TR)Y^BO\___2(7`#X54
M____9@\?1```3(GGZ.CS__](B>_H\//__^GV_O__Z,;^___KQ>@?\___9F8N
M#Q^$```````/'T``4TB)^TB![)````!(BP5>B0``2(F$)(@````QP$B)YNB\
M\___A<!U.`^W5"00@>(`\```@?H`0```=`B!^@"@``!U'[X"````2(G?Z*#S
M__^%P`^4P`^VP.L(9@\?1```,<!(BXPDB````$@S#?^(``!U"4B!Q)````!;
MP^B/\O__9F8N#Q^$```````/'T``056Z_P,``$F)]4%454B)_;^444``4TB!
M[!@$``!(BP6\B```2(F$)`@$```QP$B)YN@Z\___A<!^:XU0_T2+)=R(``!(
M8]J`/!P`=5.%TG1;2(G:OB\```!(B>?H'_/__TB%P'1&1(GGZ"+S__](B=E(
MB>)(B>Y(B<?H(?/__TB+A"0(!```2#,%4H@``'4T2('$&`0``%M=05Q!7<-F
MD$ACV.NL1(LE=(@``$2)Y^C<\O__3(GJ2(GN2(G'Z.[R___KN^BW\?__#Q^`
M`````$B#[`B+/4:(``#HL?+__[F84T``NJ`90`"^IU%``$B)QTB#Q`CI!O3_
M_V8/'T0``$B#[`B+/1:(``#H@?+__TB)Q^BY____BST#B```Z&[R__]!N(A1
M0`!%,<FZ0#1``$R)P;[#44``2(G'2(/$".G,\___9F8N#Q^$``````"0,<##
M9F8N#Q^$``````!FD$%5051)B?R_V%%``%532(GS2('LF`0``$B+!6&'``!(
MB80DB`0``#'`2(GFZ/_X__^^+P```$R)YTB)Q>@O\O__2(7`=#I,B>:_X5%`
M`#'`Z"OZ__],B>!(B[0DB`0``$@S-1F'```/A4T!``!(@<28!```6UU!7$%=
MPP\?1```3(GGZ*CP__](B=^^[E%``$&)Q>CH\?__2(G##Q]$``!(A=MTH8`[
M``^$H@```$B%[70/2(G>2(GOZ-+Q__^%P'1V2(G?Z&;P__^)P4B8@'P#_R]U
M$8/I`4ACT8!\$_\OQ@03`'3O08U$#0$]_P,```^/4/___[[R44``,<!-B>"Y
M\%%``$B-O"2`````2(G:Z'OP__](B>9(C;PD@````.A[\/__A<!U#P^W1"00
M9B4`\&8]`(!T2+[N44``,?_H//'__TB)P^E4____#Q]``$B%[70;N0(```"_
MB5%``$B)[O.F#Y?`'`"$P'3+#Q\`NXE10`"Y`0```.EG____D+X!````2(V\
M)(````#H;O#__X7`=:)(C;0D@````+_A44``Z-CX__](C;PD@````.CK\/__
MZ9[^___H8>___Y`/MA=(B?B$TG099@\?1```2(/'`8#Z+P^V%T@/1,>$TG7N
MP\-F9BX/'X0``````)!(A?\/A)<```"`/P`/A(X```!32(G[Z"7O__](C50#
M_T@YTW(4ZR=F#Q^$``````!(@^H!2#G3=!J`.B]T\NL%@#HO="-(@^H!2#G3
M<O)(.=-U%8`Z+W18O_!10`!;Z4WP__^`.B]U"4B#Z@%(.=-R\D@IVC'`2(U*
M`DB!^0`$``!W%DB#P@%(B=Z_H*I``.@L\/__N*"J0`!;PP\?1```OXE10`#I
M!O#__V8/'T0``+^)44``6^GU[___#Q]$``!(@^Q(\P]O!70I``"_^5%``/,/
M;PUW*0``2(L%L(0``$B)1"0X,<`/MP5R*0``#RE$)!!FB40D,#'`#RE,)"#H
M#/?__S'`OP)20`#H`/?__S'`OPI20`#H]/;__S'`OQ-20`#HZ/;__S'`OQI2
M0`#HW/;__S'`ORI20`#HT/;__S'`O]A10`#HQ/;__S'`OS920`#HN/;__S'`
MOT!20`#HK/;__S'`OTI20`#HH/;__S'`O^%10`#HE/;__S'`2(UT)`R_5%)`
M`.BS]?__2(7`=`](B<:_0%)``#'`Z._V__\QP$B-="0,OV520`#HCO7__TB%
MP'0/2(G&OW=20``QP.C*]O__,<!(C70D#+^"4D``Z&GU__](A<!T-$B)QK_8
M44``,<#HI?;__S'`OJY20`"_&E)``.B4]O__2(M$)#A(,P6(@P``=69(@\1(
MPY`QP$B-="0,OY)20`#H'_7__TB%P'0:2(G&OS920``QP.A;]O__Z[1F#Q^$
M``````!(C70D(;^C4D``N0H```#SI@^7P!P`A,!UD4B-="0KOS920``QP.@E
M]O__Z7O____HN^S__V9F+@\?A```````2(/L&$B+!06#``!(B40D"#'`BP5X
M?@``@_C_=!-(BW0D"$@S->>"``!U.DB#Q!C#2(UT)`2_-E)``#'`Z'_T__](
MB<(QP$B%TG02#[82@/HP#Y7!,<"$T@^5P"'(B04M?@``Z[CH1NS__V8/'T0`
M`$B#[`CHU^W__XG'Z.#M__](A<!T`TB+`$B#Q`C##Q\`05152(G]O[!20`!3
M2(/L$$B+!6F"``!(B40D"#'`2(UT)`3H"/3__TB)[DB%P'0(@#@`2(G#=2B_
ML%)``#'`Z#SU__](BT0D"$@S!3""``!U6DB#Q!!;74%<PP\?1```2(G'Z'CM
M__](A<!UUTB)[^B[Z___2(G?28G$Z+#K__])C7P$`NBVZ___OO)10`!)B=A(
MB>I)B<1(B<>Y[E%``#'`Z.GK__],B>;KC.AOZ___9F8N#Q^$```````/'T``
M059!54F)_;_844``05154TB![&"!``!(BP6B@0``2(F$)%B!```QP$B-="00
M2,>$))````#,4D``2,>$))@```")44``2,>$)*``````````2,>$)-````!W
M4D``2,>$)-@```#24D``2,>$).````#94D``2,>$).@```#A4D``2,>$)/``
M``#F4D``2,>$)/@`````````2,>$)+````#`4D``2,>$)+@```#J4D``2,>$
M),``````````Z*[R__](A<!T"8`X``^%8`0``#'`Z$G^__](B<-(A<`/A-T#
M``!(B=_HA>K__TB-?``!Z(OJ__^`.P!)B<1T(DR)Y0^V$TB)[S'`OO-20`!(
M@\,!2(/%`NBVZO__@#L`=>%(C9PDV````+]W4D``ZQ-FD$B#PPA(BWOX2(7_
M#X1S`0``2(UT)!`QP.@C\O__2(G%2(7`=-N`.`!TUDB)Q^CN]O__A<!TRDB)
M[^ARZ___2(G#2(7`#X0Z`0``9@\?1```2(G>BQ9(@\8$C8+__O[^]](AT"6`
M@("`=.F)PL'J$*F`@```#T3"2(U6`D@/1/*)P0#!3(GA2(/>`T@IWHLY2(/!
M!(V'__[^_O?7(?@E@("`@'3IB<+!ZA"I@(````]$PDB-40)(#T3*B<(`PDB#
MV0-,*>&-K`X$!```2&/M2(GOZ'KI__^^_5)``$V)X4B)VDB)QTF)QD&X^%)`
M`#'`N?!10`#HI^G__[[``0``3(GWZ/KJ__^#^/]U'F1(BQ0E`````$B+!=UX
M``!$BP0"08/X$0^%M0(``$B-="003(GWZ,KI__^)PX7`#X2P````28M5`$B+
M/8U_``!,B?$QP+[P4T``,>WHM.K__TB+C"18@0``2#,-)7\``$B)Z`^%DP0`
M`$B!Q&"!``!;74%<05U!7L,Q[68N#Q^$``````!(8\5(BYS$D````$B%VW1`
M@#L`=#M(B=^#Q0'H</7__X7`=-Q(B=_H].G__TB)PTB%P`^%B/[__TACQ4B+
MG,20````2(7;=<@/'X0``````#';Z6G^__]F#Q^$```````/MT0D(&8E`/!F
M/0!`#X4]____1(MD)"3HP^G__T$YQ`^%*O___P^W1"0@9B7_`68]P`$/A1?_
M__](B>_H'^C__TB-="00OP930`!(B<4QP.C[[___2(7`#X3R`0``2(G'Z%KI
M__])BWT`2(G&Z*[V__])B<1(A<`/A-(!``!,B>?HRN?__X/X`WXX2&/0OPM3
M0`"Y!0```$F-=!3\\Z8/E\*`V@"$TG4:@_@$#X2Q`@``@^@$2)A!@'P$_R\/
MA*`"```QP.C&^O__A<!U%4R)YS'VZ%CI__]!B<2%P`^%=@$``+ZN4D``OS92
M0``QP.BL\/__Z$?I__^Y\%%``$R)\DB)[T&)P$&YB%%``+XD4T``,<#HE^?_
M_^M+#Q]$``!D2(L4)0````!(BP78=@``@SP"$75"Z`7I__](@^P(@\,!3(GR
M:(A10`!!B<!!B=FY\%%``+XR4T``2(GO,<#H3.?__UA:OL`!``!(B>_HG>C_
M_X/X_W2H3(GWZ&#G__](B>Z_V%%``#'`Z!'P__](B>_HB?K__^G0_?__#Q]`
M`+_`4D``,>WK$@\?@`````!(8\5(B[S$L````$B%_W1R2(UT)!`QP(/%`>B!
M[O__2(7`=-R`.`!TUTB)Q^C?Y___2(G#2(7`=,?IU?O__TF+50!(BSWO?```
M3(GQ,<"^J%-``#'MZ!;H___I7?W__Y!(B<=(B40D".@#^O__2(M$)`A(B<?H
MEN?__TB)Q>DZ_?__OPT```"[Q5)``.@?YO__28G$Z93[__\/'X``````38ME
M`.DE_O__N@(```!(Q\;N____B<?HY.?__[H&````2(VT)%`!``!$B>?HW^?_
M_X"\)%`!````=0Z`O"11`0``0P^$"@$``#'2,?9$B>?HJ^?__S'`Z(0:``!(
MB</K$HG"2(VT)%`!``!(B=_HS1H``+H`@```2(VT)%`!``!$B>?HB.?__X7`
M?]5$B>=,C:0D``$``.B$Y___2(G>2(V\)``!``!(C9PD(`$``.@L'```3(UK
M*`\?A```````00^V%"1(B=^^\U)``#'`2(/#`DF#Q`'HA.7__TDYW77?QH0D
M2`$```!!N8A10`!,C80D(`$``+GP44``3(GROA530`!(B>\QP.A2Y?__Z17^
M__]-BVT(387M#X13_?__3(GOZ-CD__](@_@##X9!_?__28UT!?R_$%-``+D%
M````\Z8/E\`<`(3`30]$Y>D@_?__@+PD4@$``$$/A>C^__^`O"13`0``0P^%
MVO[__X"\)%0!``!(#X7,_O__@+PD50$``$4/A;[^__^Z`@```$C'QL;___]$
MB>?H8>;__[HI````2(VT)%`!``!$B>?H7.;__T&YB%%``$R-A"10`0``Z3#_
M___H).3__P\?0`!54TB#[!B+/;1Z``!(BP5M>@``2(E$)`@QP.@1Y?__BSV;
M>@``2(G#Z`/E__](C70D!+\:4D``#[:3N````(B0N0```#'`Z.7K__](A<!T
M"8`X,0^$EP$``#'`Z%#U__^+/5IZ``#HQ>3__[D#````N@$```"^0U-``$B)
MQ^C>Y?__2(G#2(7`=#-(BT`0BSTL>@``2(LHZ)3D__^Z15-``$B)QTB)[NBD
MY/__2(M#$$B+&/9##D`/A7,!``"+/?UY``#H:.3__[D#````N@$```"^2E-`
M`$B)Q^B!Y?__2(G#2(7`=#U(C70D!+_A44``,<#H..O__TB)Q4B%P`^$_```
M`$B+0Q"+/;)Y``!(BQCH&N3__TB)ZDB)WDB)Q^@LY/__BSV6>0``Z`'D__^Z
M`0```+Y,4T``2(G'Z"_E__^+/7EY``!(B</HX>/__[IA4T``2(G>2(G'Z/'C
M__^+/5MY``#HQN/__TB-="0$O]A10`#&@+D`````,<#HKNK__TB)!=]X``!(
MA<!T-[[``0``2(G'Z%7D__^-4`&#^@%V"8/X$0^%GP```$B+1"0(2#,%R'@`
M``^%K````$B#Q!A;7<-(BSVD>```Z._V__](B060>```2(7`=;&_2%1``.B9
MY/__9@\?A```````@'@!``^$9O[__^E:_O__D$B+!6EX``"+/;-X``!(BRA(
MBT,02(L8Z!3C__](B>Y(B=_H>>___^GX_O__#Q]``(L]BG@``.CUXO__2(G>
M2(G'Z$KD___I<O[__XG!2(L%''@``$B+%0UX``"_<%1``$B+,#'`Z!;D___H
ML>'__Y!52(G]4TB#[`CH<O+__P^V$$B)PX32=!H/'X0``````$B#P`&`^B\/
MMA!(#T38A-)U[C'`Z,?T__](A>UT(H7`=!Z`?0``=!B_^%)``+D$````2(G>
M\Z8/E\`<`(3`=`=(@\0(6UW#2(/$"$B)[UM=Z=OL__]F9BX/'X0```````\?
M0`````````````````!!5TR-3SA!5D%505154TB![)@"``!(BP5D=P``2(F$
M)(@"```QP$B)XDR-DH````!)B=!!BP%)BS%)@\`028/!"`_(B<!(B?%)B4#P
M2(GP2,'I($C!Z"A(P>XX)0#_``!("?!(B<Y(P>$(2,'F&('A``#_`(GV2`GP
M2`G(28E`^$TYPG6N2(VR``(```\?0`!(BT)H2#-"0$B#P@A(,T((2#-"^$B-
M#`!(P>@?2`G(@^#_2(E">$@Y\G753(L72(M?$$B+=R!(BV\83(G03(G23(M/
M"$C!ZAM(P>`%2`G0`P0DC90PF7F"6DB)V$B+="0(2#'H3"'(2(VT-9EY@EI(
M,>A$C2P"3(G*3(G(2,'H`DC!XAY-B>A("<)(B=A)P>@;B=%(,<A,(=!(,=A(
M`?!,B>Y(P>8%3`G&1(TD!DR)UDR)T$C!YAY(P>@"38GC2`GP2(MT)!!)P>L;
M2#'"08G`3"'J2(VT,YEY@EI(,<I(`?),B>9(P>8%3`G>1(T<%DR)[DG![0)(
MBU0D&$C!YAY,">Y(C901F7F"6DR)V4@Q\$&)]DPAX$PQP$C!Z1M(`=!,B=I(
MP>(%2`G*3(GA2<'L`DC!X1Y$C2P"2(GP2(M4)"!,">%,B>Y(,<A)C900F7F"
M6DC![AM!B<Q,(=A,,?!(`=!,B>I(P>(%2`GR1(T$`DR)VDG!ZP)(BT0D*$C!
MXAY,B<9,"=I)C80&F7F"6DC![AM(,=%!B=-,(>E,,>%(`<%,B<!(P>`%2`GP
M1(TT"$R)Z$G![0)(BTPD,$C!X!Y,B?9,">A)C8P,F7F"6D@QPD&)Q4PAPDPQ
MVD@!RDR)\4C!X05(P>X;2`GQ3(G&2<'H`DC!YAY$C2012(M4)#A,"<9,B>%(
M,?!)C903F7F"6DC!Z1M!B?!,(?!,,>A(`=!,B>)(P>(%2`G*3(GQ2<'N`DC!
MX1Y$C1P"2(GP2(M4)$!,"?%,B=Y(,<A)C905F7F"6DC![AM!B<Y,(>!,,<!(
M`=!,B=I(P>(%2`GR1(TL`DR)XDG![`)(BT0D2$C!XAY,B>Y,">))C80`F7F"
M6DC![AM(,=%!B=1,(=E,,?%(`<%,B>A(P>`%2`GP1(T$"$R)V$G!ZP)(BTPD
M4$C!X!Y,B<9,"=A)C8P.F7F"6DC![AM(,<)!B<-,(>I,,>)(`<I,B<%(P>$%
M2`GQ3(GN2<'M`DC!YAY$C3012(M4)%A,">Y,B?%(,?!)C904F7F"6DC!Z1M!
MB?5,(<!,,=A(`=!,B?)(P>(%2`G*3(G!2<'H`DC!X1Y$C20"2(GP2(M4)&!,
M"<%,B>9(,<A)C903F7F"6DC![AM!B<A,(?!,,>A(`=!,B>)(P>(%2`GR1(T<
M`DR)\DB+1"1H2,'B'DG![@),B=Y,"?))C80%F7F"6DC![AM(,=%!B=9,(>%,
M,<%(`<%,B=A(P>`%2`GP1(TL"$R)X$G![`)(BTPD<$C!X!Y,B>Y,">!)C8P(
MF7F"6DC![AM(,<)!B<1,(=I,,?)(`<I,B>E(P>$%2`GQ3(G>2<'K`DC!YAY$
MC0012(M4)'A,"=Y,B<%(,?!)C906F7F"6DC!Z1M!B?-,(>A,,>!(`=!,B<)(
MP>(%2`G*3(GI2<'M`DC!X1Y$C30"2(GP2(N4)(````!,">E,B?9(,<A)C904
MF7F"6DC![AM!B<U,(<!,,=A(`=!,B?)(P>(%2`GR1(TD`DR)PDG!Z`)(BX0D
MB````$C!XAY,B>9,"<))C80#F7F"6DC![AM(,=%!B=!,(?%,,>E(`<%,B>!(
MP>`%2`GP2(NT))````!$C1P(3(GP2<'N`DC!X!Y)C;0UF7F"6DV)W4P)\$G!
M[1M(,<*)P4PAXDPQPD@!\DR)WDC!Y@5,">Z)]D@!\DR)YDG![`)(P>8>08G5
M3`GF3(ND))@```!(,?!,(=A/C80@F7F"6DV)[$@QR$G![!M,`<!-B>A)P>`%
M30G@18G`3`'`38G82<'K`DG!X!Y!B<1-"=A)B?.)]D@#M"2H````33'#1#':
M3(N<)*````!*C8P9H>O9;DV)XT@!T4R)XDG!ZQM(P>(%3`G:B=)(`=%,B>I)
MP>T"2,'B'D&)RTP)ZDV)Q46)P$P#A"2P````23'51#'H38G=2(VT!J'KV6Y,
MB=A)P>T;2,'@!4P)Z(G`2`'P3(GF2<'L`DC!YAY!B<5,">9)B=2)TDDQ]$0Q
MX4V)[$@#E"2X````38V$"*'KV6Y,B>E)P>P;2,'A!4P)X8G)20'(3(G92<'K
M`DC!X1Y%B<1,"=E)B?.)]D@#M"3`````23'+1#'838GC2(V4`J'KV6Y,B>!)
MP>L;2,'@!4P)V(G`2`'"3(GH2<'M`DC!X!Y!B=-,">A)B<V)R4@#C"3(````
M23'%13'H38G=3HV$!J'KV6Y,B=Y)P>T;2,'F!4P)[HGV3`'&38G@2<'L`DG!
MX!Y!B?5-">!)B<2)P$TQQ$0QXDV)[$B-C!&AZ]EN3(GJ2,'B!4G![!M(`X0D
MT````$P)XHG22`'13(G:2<'K`DC!XAY!B<Q,"=I-B<-%B<!,`X0DV````$DQ
MTT0QWDV)XTB-M#"AZ]EN3(G@2<'K&TC!X`5,"=B)P$@!\$R)[DG![0)(P>8>
M08G#3`GN28G5B=)(`Y0DX````$DQ]40QZ4V)W4V-A`BAZ]EN3(G92<'M&TC!
MX05,">F)R4D!R$R)X4G![`)(P>$>18G%3`GA28GTB?9),<Q$,>!-B>Q(C90"
MH>O9;DR)Z$G![!M(P>`%3`G@B<!(`<),B=A)P>L"2`.T).@```!(P>`>08G4
M3`G828G+B<E(`XPD\````$DQPT4QV$V)XTZ-A`:AZ]EN3(GF2<'K&TC!Y@5,
M"=Z)]DP!QDV)Z$G![0))P>`>08GS30GH28G%B<!(`X0D^````$TQQ40QZDV)
MW4B-C!&AZ]EN3(G:2<'M&TC!X@5,">J)TD@!T4R)XDG![`)(P>(>08G-3`GB
M38G$18G`23'41#'F38GL2(VT,*'KV6Y,B>A)P>P;2,'@!4P)X(G`2`'P3(G>
M2,'F'DG!ZP)!B<1,`X0D``$``$P)WDF)TXG22`.4)`@!``!),?-$,=E-B>--
MC80(H>O9;DR)X4G!ZQM(P>$%3`G9B<E)`<A,B>E)P>T"2,'A'D6)PTP)Z4F)
M]8GV2`.T)!`!``!),<U$,>A-B=U(C90"H>O9;DR)V$G![1M(P>`%3`GHB<!(
M`<),B>!)P>P"2,'@'D&)U4P)X$F)S(G)23'$13'@38GL3HV$!J'KV6Y,B>Y)
MP>P;2,'F!4P)YHGV3`'&38G82<'K`DG!X!Y!B?1-"=A)B<-(`XPD&`$``(G`
M33'#2`.$)"`!``!$,=I-B>-(C8P1H>O9;DR)XDG!ZQM(P>(%3`G:B=)(`=%,
MB>I)P>T"2,'B'D&)RTP)ZDV)Q46)P$P#A"0H`0``23'51#'N38G=2(VT,*'K
MV6Y,B=A)P>T;2,'@!4P)Z(G`2`'P3(GF2<'L`DC!YAY!B<5,">9)B=2)TD@#
ME"0P`0``23'T1#'A38GL38V$"*'KV6Y,B>E)P>P;2,'A!4P)X8G)20'(3(G9
M2<'K`DC!X1Y%B<1,"=E)B?.)]DDQRT0QV$V)XT@#M"0X`0``2(V4`J'KV6Y,
MB>!)P>L;2,'@!4P)V$2-'!!,B>A)P>T"2,'@'DP)Z$F)S8G)23'%B<)%,>A-
MB=U.C80&H>O9;DR)WDG![1M(P>8%3`GN3(NL)$`!``!&C30&38G@2<'L`DG!
MX!Y-">!,"<!$B<9)B<1(B=!((?!-(=Q)"<2XW+P;CTD!Q4P!Z4V)]4D!S$R)
M\4G![1M(P>$%3`GI28GU00',3(G92<'K`DC!X1Y,"=E!B<M)"<A-(?!-(=U-
M">A,BZPD2`$``$D!Q4P!ZDV)Y4D!T$R)XDG![1M(P>(%3`GJ1HTL`DR)\DG!
M[@)(P>(>3`GR38G>08G02`G132'&3"'A3`GQ3(NT)%`!``!)`<9,`?9-B>Y(
M`?%,B>Y)P>X;2,'F!4P)]D2--`Y,B>9)P>P"2,'F'DP)YDV)Q(GQ2`GR22',
M3"'J3`GB3(ND)%@!``!)`<1-`>--B?1,`=I-B?-)P>,%2<'L&TT)XT6-)!--
MB>M)P>T"2<'C'DT)ZTF)S42)VDP)WDDAU4PA]DP)[DR+K"1@`0``20'%30'H
M38GE3`'&38G@2<'M&TG!X`5-">A%C2PP38GP2<'N`DG!X!Y-"?!)B=9$B<9-
M"<-)(?9-(>--"?-,B[0D:`$``$D!QDP!\4V)[DD!RTR)Z4G![AM(P>$%3`GQ
M1HTT&4R)X4G![`)(P>$>3`GA28GT08G+20G(32'H32'<30G@3(ND)'`!``!)
M`<1,`>)-B?1)`=!,B?))P>P;2,'B!4P)XD:-)`),B>I)P>T"2,'B'DP)ZDV)
MW4&)T$@)T4TAQ4PA\4P)Z4R+K"1X`0``20'%3`'N38GE2`'Q3(GF2<'M&TC!
MY@5,">Y$C2P.3(GV2<'N`DC!YAY,"?9-B<:)\4@)\DDASDPAXDP)\DR+M"2`
M`0``20'&30'S38GN3`':38GK2<'C!4G![AM-"?-%C30338GC2<'L`DG!XQY-
M">-)B<Q$B=I,"=Y)(=1,(>Y,">9,BZ0DB`$``$D!Q$T!X$V)]$P!QDV)\$G!
M[!M)P>`%30G@18TD,$V)Z$G![0))P>`>30GH28G51(G&30G#22'U32'S30GK
M3(NL))`!``!)`<5,`>E-B>5)`<M,B>%)P>T;2,'A!4P)Z4:-+!E,B?%)P>X"
M2,'A'DP)\4F)]DD)R$&)RTTAWDTAX$T)\$R+M"28`0``20'&3`'R38GN20'0
M3(GJ2<'N&TC!X@5,"?)&C30"3(GB2<'L`DC!XAY,">)-B=Q!B=!("=%-(<1,
M(>E,">%,BZ0DH`$``$D!Q$P!YDV)]$@!\4R)]DG![!M(P>8%3`GF1(TD#DR)
M[DG![0)(P>8>3`GN38G%B?%("?))(<U,(?),">I,BZPDJ`$``$D!Q4T!ZTV)
MY4P!VDV)XTG![1M)P>,%30GK18TL$TV)\TG![@))P>,>30GS28G.1(G:3`G>
M22'63"'F3`GV3(NT)+`!``!)`<9-`?!-B>Y,`<9-B>A)P>X;2<'@!4T)\$6-
M-#!-B>!)P>P"2<'@'DT)X$F)U$2)QDT)PTDA]$TAZTT)XTR+I"2X`0``20'$
M3`'A38GT20'+3(GQ2<'L&TC!X05,">%&C2093(GI2<'M`DC!X1Y,">E)B?5!
MB<M)"<A-(?!-(=U-">A,BZPDP`$``$D!Q4P!ZDV)Y4D!T$R)XDG![1M(P>(%
M3`GJ1HTL`DR)\DG![@)-B=A(P>(>3`GR08G62`G132'P3"'A3`G!3(N$),@!
M``!)`<!,`<9-B>A(`?%,B>Y)P>@;2,'F!4P)QD2-!`Y,B>9)P>P"3(GQ2,'F
M'DP)YD&)]$@)\DPAX4PAZD@)RDB+C"30`0``2`'!20'+3(G!2`.$)-@!``!,
M`=I-B<-(P>$%3`'P2<'K&TP)V8G)2`'*3(GI2<'M`DC!X1Y!B=-,">E-B>5!
MB<]("<Y-(?U,(<9,">Y-B=U(`?!,B=Y)P>T;2,'F!4P)[HGV2`'P3(G&2<'H
M`DC!YAY!B<5)"?"^UL%BRDPQP3'*2(N,).`!``!(`?%)`<Q,B>E,`>)-B>Q(
MP>$%2<'L&TP)X8G)2`'*3(G92,'A'DG!ZP)!B=1)"<M,B<%-B>9%B<!,,=E)
MP>X;,<A(BXPDZ`$``$@!\4D!STJ-##A,B>!(P>`%3`GPB<!,C30!3(GH2<'M
M`DR)V4C!X!Y%B?=%B=M)"<5(BX0D\`$``$PQZ4@!\#'*3(GY3`'`2,'I&T@!
MPDR)^$C!X`5("<A(BXPD^`$``(G`2`'"3(G@2`'Q2<'L`DC!X!Y,`=E-B>M!
MB=!,">!-B<1%B>U),<-)P>P;13'>3HT<,4R)P4C!X05,">&)R4D!RTR)^4G!
M[P)(P>$>18G<20G/2(N,)``"``!(`?%,`>E)B<6)P$TQ_40QZDR-+!%,B>),
MB>%(P>D;2,'B!4@)RDR)P4G!Z`*)TDC!X1Y)`=5(BY0D"`(``$P)P4V)^$DQ
MR$6)[D6)_T@!\D4QPT@!T$R)\DZ-!!A,B?!(P>H;2,'@!4@)T$B)RHG)B<!)
M`<!,B>!)P>P"2,'@'D6)PTD)Q$B+A"00`@``3#'B2`'P03'53(G:3`'X20'%
M3(G82,'@!4C!ZAM("=!,B?))P>X"B<!(P>(>20'%2(N$)!@"``!,"?)%B>](
M`?!(`<A,B>%%B>1(,=%!,<A,B?E)`<!,B?A(P>D;2,'@!4@)R(G`20'`3(G8
M2<'K`DC!X!Y%B<9)"<-(BX0D(`(``$R)\4C!Z1M(`?!,`>!)B=2)TDTQW$4Q
MY4Z-)"A,B?!(P>`%2`G(2(N,)"@"``")P$D!Q$R)^$@!\4G![P)(P>`>2`'*
M3(G918GE3`GX18G;2#'!03'(3(GI20'03(GJ2,'I&TC!X@5("<J)TDD!T$R)
M\DG![@)(P>(>18G'20G62(N4)#`"``!,B?E(P>D;2`'R3`':28G#B<!-,?-%
M,=Q.C1PB3(GZ2,'B!4@)RDR)Z4G![0*)TDC!X1Y)`=-(BY0D.`(``$P)Z46)
MW$@!\D@!T$R)\D6)]D@QRD$QT$R)XDD!P$R)X$C!ZAM(P>`%2`G02(G*B<F)
MP$D!P$R)^$G![P)(P>`>18G%20G'2(N$)$`"``!(`?!,,?I,`?!!,=-,B>I)
M`<-,B>A(P>H;2,'@!4@)T$R)XDG![`*)P$C!XAY)`<-(BX0D2`(``$P)XD6)
MWDF)U$@!\$@!R$R)^46)_T@QT8G203'(2HT,`$R)\$V)\$G!Z!M(P>`%3`G`
MB<!(`<%,B>A)P>T"2,'@'D&)R$D)Q4B+A"10`@``33'L2`'P13'C38G$3`'X
M2<'L&TD!PTR)P$C!X`5,">")P$D!PTR)\$C!X!Y)P>X"18G<3`GP3(NT)%@"
M``!)`?9)`=9,B>I%B>U(,<(QT4F-%`Y,B>%-B>9)P>X;2,'A!4P)\8G)2`'*
M3(G!2<'H`DC!X1Y!B=9)"<A(BXPD8`(``$@!\4P!Z4F)Q8G`33'%13'K38GU
M20'+3(GQ2<'M&TC!X05,">F)R4D!RTR)X4G![`)(P>$>18G=20G,2(N,)&@"
M``!(`?%(`<A,B<%%B<!,,>$QRDB-#!!,B>A,B>I(P>H;2,'@!4@)T$R)\DG!
M[@)(P>(>B<!)"=9(BY0D<`(``$@!P8G(2`'R3`'"38G@33'P13'#28G`3`':
M28G#2<'@!4G!ZQM-"=A)B<-(P>@"2<'C'D$!T$R)ZDG![0))"<-(BX0D>`(`
M`$C!XAY)"=5$B>)!`=M(`?!$`>U,B5\02`'"3(GP2(EO&$PQZ#'!2(T$"DR)
MPDR)P44!R$C!X@5(P>D;3(E'"$@)R@'000'"1`-W($R)%TR)=R!(BX0DB`(`
M`$@S!8UA``!U$DB!Q)@"``!;74%<05U!7D%?P^@4R___#Q]``$B#[`B_@```
M`.@BR___NHFKS>^Y_MRZF+[PX=+#2,<``2-%9TB)4`A(B4@02,=`&'94,A!(
MB7`@2,=`*`````!(QT`P`````,=`>`````!(@\0(PV9F+@\?A```````D$%7
M2&/"059)B<9!54%428G\54F-;"0X4TB)\TB#[`A(BW<H2(M7,(T,QD@Y\4B)
M3RA(@](`2,'H'4@!T$B)1S!(8W]XA?]T5D&]0````$B)WD$I_44Y[D4/3NY(
M`>]-8_U,B?KHI\W__T&+1"1X1`'H08E$)'B#^$!T%4B#Q`A;74%<05U!7D%?
MPV8/'T0``$R)YT4I[DP!^^CRZ/__08/^/P^.W````$&#[D!%B?=!P>\&18G]
M28/%`4G!Y09)`=WS#V\#3(GG2(/#0`\110#S#V]+T`\131#S#V]3X`\152#S
M#V];\`\173#HH.C__TPYZW7,0<'G!D4I_DECQDB#^`AR6TF+50!)B50D.$F+
M5`7X2(E4!?A(C54(2(/B^$@IU4DI[4@!Q4B#Y?A(@_T(<AA(@^7X,<!)BTP%
M`$B)#`)(@\`(2#GH<NY%B70D>$B#Q`A;74%<05U!7D%?PY"H!'4H2(7`=.)!
M#[95`$&(5"0XJ`)TU$$/MU0%_F:)5`7^Z\=)B=WI</___T&+50!!B50D.$&+
M5`7\B50%_.NK059,C78X055!5%5(B?U32(M&*$B)\T2+9BA$BVXP2,'H`X/@
M/T$/S$$/S8U(`4B8QD0&.(!(8\%,`?"#^3@/CB`!``"Z0````"G*B=%T#S'2
MB=:#P@'&!#``.<IR\TB)W^B*Y___9@_OP`\10SA)QT8P`````$$/$48000\1
M1B!$B6MP2(G?1(EC=.A@Y___2(L#2(G?2,'H&(A%`$B+`TC!Z!"(10%(BP-(
MP>@(B$4"2(L#B$4#2(M#"$C!Z!B(101(BT,(2,'H$(A%!4B+0PA(P>@(B$4&
M2(M#"(A%!TB+0Q!(P>@8B$4(2(M#$$C!Z!"(10E(BT,02,'H"(A%"DB+0Q"(
M10M(BT,82,'H&(A%#$B+0QA(P>@0B$4-2(M#&$C!Z`B(10Y(BT,8B$4/2(M#
M($C!Z!B(11!(BT,@2,'H$(A%$4B+0R!(P>@(B$422(M#(%N(11-=05Q!74%>
MZ4S(__^Z.````#'_*<J#^@AS+O;"!'5KA=(/A`'____&``#VP@(/A/7^__\Q
MR6:)3!#^Z>G^__]F#Q^$``````")T4C'``````!(QT0(^`````!(C4@(2(/A
M^$@IR`'"@^+X@_H(#X*U_O__@^+X,<")QH/`"$B)/#$YT'+SZ9[^___'````
M``#'1!#\`````.F+_O__2(L%!%D``$B#^/]T)%5(B>532(/L"+M0JD``_]!(
M@^L(2(L#2(/X_W7Q2(/$"%M=P\,`2(/L".APSO__2(/$",,````N`"XN`"5S
M+R5S`"]P<F]C+V-U<G!R;V,O9FEL90!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,
M;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`4$%27U1%35``4$%27U!23T=.
M04U%`#H`+P`E<R5S)7,`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),
M24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?
M1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]4
M35!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#
M3$5!3@!005)?0TQ%04X]`#$`3$1?3$E"4D%265]0051(`%5315(`4UE35$5-
M`"]T;7`O`%1-4$1)4@!414U01$E2`%1%35``5$U0`%5315).04U%`"4P,G@`
M<&%R+0`E<R5S)7,E<P!0051(`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E
M<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`&`!P97)L`#``4$%2.CI0
M86-K97(Z.E9%4E-)3TX`,2XP-3(`+64`+2T`````7U]%3E9?4$%27T-,14%.
M7U\@("`@("`@("`@("`@("```````````'!E<FQX<VDN8P`````````E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE
M<G)N;STE:2D*```````````````````E<SH@<')I=F%T92!S=6)D:7)E8W1O
M<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y
M;W5R(&]P97)A=&EO;BD*````````56YA8FQE('1O(&-R96%T92!C86-H92!D
M:7)E8W1O<GD``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE
M('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``````````&5V
M86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P
M.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A
M<E]P;#L*;7D@*"1005)?34%'24,L("1P87)?=&5M<"P@)'!R;V=N86UE+"!`
M=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,
M14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S
M96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z
M.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I
M;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E
M<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M
M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@
M;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-
M4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID
M:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@
M,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T
M;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@
M+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE
M;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G
M)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N
M86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B([
M"G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O
M8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"
M14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT
M97)N86QS.CI005(Z.D)/3U0["B1005)?34%'24,@/2`B7&Y005(N<&U<;B([
M"F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!
M4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@
M/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/
M(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?
M9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G
M+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@
M*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?
M7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64@;W(@
M;&%S=#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1C
M:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I
M>F4@/#T@)&-H=6YK7W-I>F4I('L*)&UA9VEC7W!O<R`](#`["GT@96QS:68@
M*"AM>2`D;2`]("1S:7IE("4@)&-H=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?
M<&]S(#T@)'-I>F4@+2`D;3L*?2!E;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE
M("T@)&-H=6YK7W-I>F4["GT*=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS
M965K(%]&2"P@)&UA9VEC7W!O<RP@,#L*<F5A9"!?1D@L("1B=68L("1C:'5N
M:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN
M9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["B1M86=I8U]P;W,@*ST@
M)&D["FQA<W0["GT*)&UA9VEC7W!O<R`M/2`D8VAU;FM?<VEZ93L*?0IL87-T
M(&EF("1M86=I8U]P;W,@/"`P.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L
M(#`["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M
M(#0@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?
M1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@
M("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B
M"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA
M;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B
M+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX
M?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@
M*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@
M*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI
M)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B
M=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@
M/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE
M?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H
M;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE
M;F%M92`](%]S879E7V%S*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D[
M"F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER
M95]L:7-T>R1F=6QL;F%M97T@/0HD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]
M('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M
M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U
M8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D
M;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`](&1E;&5T92`D<F5Q=6ER
M95]L:7-T>R1M;V1U;&5](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O
M;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N
M9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE
M.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F
M?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@
M)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O
M+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F
M:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO
M9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR
M97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@
M/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.
M0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H
M)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64[
M"GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S
M:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[
M)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T
M(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@
M("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B
M=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?
M05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I
M='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=]
M.PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I
M;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB
M7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@
M('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%2
M1U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!
M4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A
M<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*
M)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S
M=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE
M;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q
M(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q
M(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD
M8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L
M92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*
M?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O
M<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS
M:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!
M4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D
M14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H
M:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U
M:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$
M:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP
M.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D
M<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=
M.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP
M+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E
M861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E96YV(#T@9&\@>PII
M9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY
M;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>
M7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I]
M.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D
M<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=
M.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I
M<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B
M.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/
M.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ
M1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L
M"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD
M9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF
M("AD969I;F5D("1D871A7W!O<RD@>PIR96%D(%]&2"P@)&QO861E<BP@)&1A
M=&%?<&]S.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@
M/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@
M/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R
M+"`D,"D["GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM
M>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L
M(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B
M("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME
M>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I
M8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI
M*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*:68@*"1B=6YD;&4I('L*
M<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC
M(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET
M92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD
M"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*
M<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I
M;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L
M('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML
M:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@
M)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@
M>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@
M/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC
M*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE
M+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\
M7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L
M94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA
M<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B
M)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I
M;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF
M("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD[
M"F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D
M9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*
M:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*
M96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)&9H+"`G/#IR87<G
M+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C
M;VYT96YT(#T@/"1F:#X["F-L;W-E("1F:#L*4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\
M86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY
M*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%
M(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X
M>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@
M)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT
M*3L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"B1Z:7`M/G=R
M:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S
M=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N
M9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I
M9V5S=#HZ4TA!+3YN97<H,2D["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D;W5T
M.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E("1F:#L*)&-A8VAE7VYA;64@
M/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T
M,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(
M12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH
M)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN
M="@D4$%27TU!1TE#*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*
M97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I
M>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S
M(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R
M)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI:
M:7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ
M6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R
M;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;
M17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI
M=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ
M3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D
M>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q6UPD14Y6
M>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I
M;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE
M>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]
M("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@
M/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO
M*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*
M?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I
M;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA
M;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N
M8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R
M7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE
M(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M
M92(@=&\@(B1D97-T7VYA;64B72D["B1M96UB97(M/F5X=')A8W14;T9I;&5.
M86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@
M)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E
M.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S
M<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I
M;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@
M/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D
M;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E
M;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S
M92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z
M.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A
M=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E
M<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E
M<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@
M=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U
M:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%
M>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@
M0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4[
M"G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!0
M05(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@
M?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A
M;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"
M=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R
M92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS
M8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A
M<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[
M4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N
M.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%2
M7U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q4
M14U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N
M9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W
M=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D
M("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U
M<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D
M("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R
M;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%
M32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D
M<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA
M;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!
M3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P
M96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T
M(')E860@(B1P<F]G;F%M92(Z("0A73L*<V5E:R`D9F@L("TQ."P@,CL*;7D@
M)&)U9CL*<F5A9"`D9F@L("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%
M(BD@>PIS965K("1F:"P@+34X+"`R.PIR96%D("1F:"P@)&)U9BP@-#$["B1B
M=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A
M8VAE+21B=68B.PI]"F5L<V4@>PIM>2`D9&EG97-T(#T@979A;`I["G)E<75I
M<F4@1&EG97-T.CI32$$["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I
M.PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#
M86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["B1C='@M/F%D9&9I;&4H)&9H
M*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T.PI]('Q\("1M=&EM93L*
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21D:6=E<W0B.PI]
M"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!
M4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S
M=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.
M5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D
M;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@
M(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY
M("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXZ
M<F%W)RP@)'1E;7!N86UE(&]R(&1I92!Q<5M#86XG="!W<FET92`B)'1E;7!N
M86UE(CH@)"%=.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H
M;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE
M*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*
M?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@
M*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'
M3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M
M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N
M86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S
M='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@
M;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]
M"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE
M("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I
M<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI
M('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@
M)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%
M)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX
M7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.
M04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\
M(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B
M.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG
M971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ
M1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@
M<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?
M9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U
M8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK
M*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)
M6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'
M($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT[
M"GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6
M>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T
M<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B
M7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM0
M05)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H
M(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]
M('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%
M3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH
M7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D
M;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@
M(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U
M<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1?
M?2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E
M;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G
M92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN
M9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ
M($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@
M9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@
M)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D
M0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>
M7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?
M15)23U(["C$["E]?14Y$7U\*```4``````````%Z4@`!>!`!&PP'")`!``!,
M````'````!B0___&`````$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#
M!T0.0`)L"@XX1`XP00XH0@X@0@X80@X00@X(20L``````"0```!L````F)#_
M_WL`````00X0@P)'#B`";`H.$$$."$$+``````!,````E````/"0__\W`@``
M`$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9$#CB#!T<.8`,5`0H..$$.,$$.
M*$(.($(.&$(.$$(."$$+`````#P```#D````X)+__T$!````0@X0C0)"#AB,
M`T$.((8$00XH@P5'#L`!>@H.*$$.($$.&$(.$$(."$,+```````D````)`$`
M`/"3__^!`````$$.$(,"2@Z@`0)O"@X000X(00L`````/````$P!``!8E/__
MR0````!"#A"-`DH.&(P#00X@A@1)#BB#!4<.P`@">@H.*$$.($$.&$(.$$(.
M"$,+`````!0```",`0``Z)3__RH`````1`X080X(`!0```"D`0```)7__T0`
M````1`X0>PX(`!0```"\`0``.)7__P,``````````````#P```#4`0``,)7_
M_[\!````0@X0C0)"#AB,`TD.((8$00XH@P5*#L`)`EP*#BA!#B!!#AA"#A!"
M#@A&"P`````4````%`(``+"6__\D```````````````L````+`(``,B6__^[
M`````%,.$(,"`DL*PPX(10MW#@A&PU`.$(,"1L,."``````<````7`(``%B7
M__^U`0```$0.4`-*`0H."$(+`````!P```!\`@``^)C__VH`````1`X@:PH.
M"$$+````````%````)P"``!(F?__'0````!$#A!8#@@`-````+0"``!0F?__
ML0````!"#A",`D$.&(8#20X@@P1$#C`"1@H.($$.&$$.$$(."$8+``````!<
M````[`(``-B9__\\!P```$(.$(X"0@X8C0-*#B",!$$.*(8%00XP@P9'#I"#
M`@.4`@H.,$$.*$$.($(.&$(.$$(."$$+`ZL!#IB#`DL.H(,"6PZ8@P)!#I"#
M`@`````L````3`,``+B@__]O`@```$$.$(8"00X8@P-$#C`#O`$*#AA!#A!!
M#@A!"P`````T````?`,``/BB__]U`````$$.$(8"1`X8@P-$#B`"6PH.&$$.
M$$$."$$+1`X81`X000X(`````"0```"T`P``X(?__^P!````00X0@P)$#D`#
MB`$*#A!!#@A!"P````!,````W`,``"BC__\,%@```$(.$(\"1@X8C@-"#B"-
M!$(.*(P%00XPA@9!#CB#!T<.T`4#YQ4*#CA!#C!!#BA"#B!"#AA"#A!"#@A!
M"P```!0````L!```Z+C__U0`````1`X0`D\."&0```!$!```,+G__Z`!````
M0@X0CP)%#AB.`T4.((T$0@XHC`5$#C"&!D8..(,'1PY``F`*#CA!#C!!#BA"
M#B!"#AA"#A!"#@A'"P+$"@XX00XP00XH0@X@0@X80@X00@X(0@L`````1```
M`*P$``!HNO__]0$```!"#A".`D8.&(T#0@X@C`1!#BB&!40.,(,&`T8!"@XH
M1`X@0@X80@X00@X(10L`````````````)````/0$``#`@O__X`,````.$$8.
M&$H/"W<(@``_&CLJ,R0B```````````!&P,[X/K__QD```"<@O__U/___WR&
M__^4_O__'(O___SZ___LB___3/O__VR,__]T^___K([__\3[___\C___!/S_
M_XR0__\L_/__7)'__VS\__^,D?__A/S__]R1__^<_/__[)'__[3\__^LD___
M]/S__]R3__\,_?__G)3__SS]__]<EO__7/W__\R6__]\_?__[);__Y3]__^L
ME___S/W__^R>__\L_O__7*'__US^___LH?__O/[___RW__\,____7+C__R3_
M___\N?__C/___P,`````````,*A````````"`````````+@%````````%P``
M```````8$D```````!0`````````!P`````````'`````````*`10```````
M"`````````!X``````````D`````````&``````````5````````````````
M````!@````````!0`D````````L`````````&``````````%`````````"`+
M0```````"@````````"=!````````/7^_V\`````P`]````````!````````
M`!H$`````````0`````````J!`````````$`````````.@0````````!````
M`````$4$`````````0````````!/!`````````$`````````700````````!
M`````````#,`````````#`````````#0%T````````T`````````>%%`````
M```=`````````&H$````````\/__;P````"T$$```````/[__V\`````<!%`
M``````#___]O``````$`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````HID``````````
M```````````````````&&$```````!880```````)AA````````V&$``````
M`$880```````5AA```````!F&$```````'880```````AAA```````"6&$``
M`````*880```````MAA```````#&&$```````-880```````YAA```````#V
M&$````````890```````%AE````````F&4```````#890```````1AE`````
M``!6&4```````&890```````=AE```````"&&4```````)890```````IAE`
M``````"V&4```````,890```````UAE```````#F&4```````/890```````
M!AI````````6&D```````"8:0```````-AI```````!&&D```````%8:0```
M````9AI```````!V&D```````(8:0```````EAI```````"F&D```````+8:
M0```````QAI```````#6&D```````.8:0```````]AI````````&&T``````
M`!8;0```````)AM````````V&T```````$8;0```````5AM```````!F&T``
M`````'8;0```````AAM```````"6&T```````*8;0```````MAM```````#&
M&T```````(A10`````````````````#_____`````+A40```````________
M__\``````````/__________````````````1T-#.B`X+C,@6T1R86=O;D9L
M>5T@4F5L96%S92\R,#$Y+3`R+3(R``````0````)````!````$=.50!G;VQD
M(#$N,38`````+G1E>'0`+F=O=``N8V]M;65N=``N9V]T+G!L=``N<F5L82YP
M;'0`+FEN:70`+F)S<P`N9'1O<G,`+F-T;W)S`"YD>6YS='(`+F5H7V9R86UE
M7VAD<@`N9VYU+G9E<G-I;VY?<@`N:6YT97)P`"YR96QA+F1Y;@`N9VYU+G9E
M<G-I;VX`+FYO=&4N9VYU+F=O;&0M=F5R<VEO;@`N9'EN<WEM`"YF:6YI`"YG
M;G4N:&%S:``N;F]T92YT86<`+F5H7V9R86UE`"YT;5]C;&]N95]T86)L90`N
M9'EN86UI8P`N<VAS=')T86(`+G)O9&%T80`N9&%T80``````````````````
M````````````````````````````````````````````````````````````
M`````````````````&8````!`````@```````````D`````````"````````
M%0````````````````````$```````````````````"T````!P````(`````
M````&`)````````8`@```````#@````````````````````$````````````
M````````G`````L````"`````````%`"0```````4`(```````#0"```````
M``0````!````"``````````8`````````$$````#`````@`````````@"T``
M`````"`+````````G00```````````````````$```````````````````"J
M````]O__;P(`````````P`]```````#`#P```````/0``````````P``````
M```(````````````````````>````/___V\"`````````+000```````M!``
M``````"\``````````,``````````@`````````"`````````%<```#^__]O
M`@````````!P$4```````'`1````````,``````````$`````0````0`````
M``````````````!N````!`````(`````````H!%```````"@$0```````'@`
M`````````P`````````(`````````!@`````````'@````0```!"````````
M`!@20```````&!(```````"X!0````````,````+````"``````````8````
M`````"@````!````!@````````#0%T```````-`7````````$P``````````
M``````````0````````````````````C`````0````8`````````\!=`````
M``#P%P```````.`#```````````````````0`````````!```````````0``
M``$````&`````````-`;0```````T!L```````"G-0``````````````````
M$````````````````````*0````!````!@````````!X44```````'A1````
M````#@````````````````````0```````````````````#K`````0````(`
M````````B%%```````"(40```````*\^```````````````````(````````
M````````````O@````$``'`"`````````#B00```````.)`````````<!0``
M````````````````"````````````````````$D````!``!P`@````````!4
ME4```````%25````````U`````````````````````0`````````````````
M``#8````!@````,`````````**9````````HE@`````````"````````!```
M```````(`````````!``````````!P````$````#`````````"BH0```````
M*)@````````(````````````````````"````````````````````!4````!
M`````P`````````PJ$```````#"8``````````(```````````````````@`
M``````````````````#S`````0````,`````````,*I````````PF@``````
M`"`````````````````````(````````````````````.@````$````#````
M`````%"J0```````4)H````````0````````````````````"```````````
M`````````#,````!`````P````````!@JD```````&":````````$```````
M``````````````@```````````````````#(`````0````,`````````<*I`
M``````!PF@`````````````````````````````(````````````````````
M+@````@````#`````````("J0```````<)H```````"A!```````````````
M````(`````````````````````P````!````,````````````````````'":
M````````*0````````````````````$``````````0````````"%````!P``
M``````````````````````"<F@```````!P````````````````````$````
M````````````````X0````,`````````````````````````N)H```````#Y
?`````````````````````0``````````````````````
